@@ -4,10 +4,9 @@
 globa=[]
 last_assignable_comm=None
 pseudo_terminal_level=0
+realtime_display_string="oijijoijo"
 rp_evaluator=lambda x:None
-current_input_text=""
-rp_pt_VARS=""
-python_input_buffers={}# str ⟶ str
 rp_evaluator_mem=None
-buffy_the_buffer_buffalo=None# Set by key bindings and read by layout
-parenthesized_line=""
\ No newline at end of file
+current_input_text=""
+rp_VARS_display=""
+python_input_buffers={}
\ No newline at end of file
