@@ -1,4 +1,6 @@
 from rp.r import *
 import rp.prompt_toolkit
 def main():
-    pseudo_terminal(locals(),globals())
\ No newline at end of file
+    pterm()
+if __name__=='__main__':
+    main()
\ No newline at end of file
