@@ -271,10 +271,14 @@ class PythonCompleter(Completer):
             if complete_event.completion_requested or self._complete_python_while_typing(document):
                 doc=Document(document.text,document.cursor_position-(origin[::-1].find('.') if '.' in origin else len(origin)),document.selection)
                 script = get_jedi_script_from_document(doc, self.get_locals(), self.get_globals())
+                # print(script)
                 pos=document.cursor_position-len(origin)+1
                 if script:
                     try:completions = script.completions()
-                    except:pass#The original ptpython has a whole string of specific error types, and it looks like visual clutter. I got rid of it to see my code more easily. I dont think im missing much.
+                    except Exception as e:
+                        import rp
+                        # rp.print_verbose_stack_trace(e)
+                        pass#The original ptpython has a whole string of specific error types, and it looks like visual clutter. I got rid of it to see my code more easily. I dont think im missing much.
                     else:
                         # fff=1
                         for c in completions:
