@@ -52,13 +52,23 @@ __all__=(
     'PythonCommandLineInterface',
 )
 
+import rp.r_iterm_comm as ric
+def set_debug_height(height):
+    ric.debug_height=height
+    return height
+
 class OptionCategory(object):
     def __init__(self,title,options):
         assert isinstance(title,six.text_type)
         assert isinstance(options,list)
 
         self.title=title
-        self.options=options
+        self._options=options
+
+    @property
+    def options(self):
+        return [option for option in self._options if option.is_visible()]
+    
 
 class Option(object):
     """
@@ -71,7 +81,7 @@ class Option(object):
             possible values to callbacks that activate these value.
     :param get_current_value: Callable that returns the current, active value.
     """
-    def __init__(self,title,description,get_current_value,get_values):
+    def __init__(self,title,description,get_current_value,get_values,is_visible=lambda:True):
         assert isinstance(title,six.text_type)
         assert isinstance(description,six.text_type)
         assert callable(get_current_value)
@@ -81,6 +91,7 @@ class Option(object):
         self.description=description
         self.get_current_value=get_current_value
         self.get_values=get_values
+        self.is_visible=is_visible
 
     @property
     def values(self):
@@ -268,6 +279,7 @@ class PythonInput(object):
                     return o
                 else:
                     i+=1
+        return category.options[-1]
 
     def get_compiler_flags(self):
         """
@@ -364,12 +376,12 @@ class PythonInput(object):
             setattr(self,attribute,False)
             return True
 
-        def simple_option(title,description,field_name,values=None):
+        def simple_option(title,description,field_name,values=None,is_visible=lambda:True):
             " Create Simple on/of option. "
             values=values or ['off','on']
 
             def get_current_value():
-                return values[bool(getattr(self,field_name))]
+                return values[bool(getattr(self,field_name,'(Broken)'))]
 
             def get_values():
                 return {
@@ -379,7 +391,8 @@ class PythonInput(object):
 
             return Option(title=title,description=description,
                           get_values=get_values,
-                          get_current_value=get_current_value)
+                          get_current_value=get_current_value,
+                          is_visible=is_visible)
         def doge(self):
             setattr(self,'sand_creature',"Option Camel")
             from doge.core import main
@@ -391,7 +404,12 @@ class PythonInput(object):
                               description='Vi or emacs key bindings.',
                               field_name='vi_mode',
                               values=['emacs','vi']),
+                simple_option(title='Microcompletions',
+                              description='When in RP-Emacs mode, should we enable microcompletions?',
+                              field_name='enable_microcompletions',
+                              values=[False,True]),
                 simple_option(title='Paste mode',
+                        # is_visible=lambda:getattr(self,'show_all_options',True),
                               description="When enabled, don't indent automatically.",
                               field_name='paste_mode'),
                 Option(title='Complete while typing',
@@ -403,6 +421,7 @@ class PythonInput(object):
                            'off':lambda:disable('complete_while_typing'),
                        }),
                 Option(title='History search',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
                        description='When pressing the up-arrow, filter the history on input starting '
                                    'with the current text. (Not compatible with "Complete while typing".)',
                        get_current_value=lambda:['off','on'][self.enable_history_search],
@@ -415,17 +434,21 @@ class PythonInput(object):
                                           'selecting text and scrolling through windows.',
                               field_name='enable_mouse_support'),
                 simple_option(title='Confirm on exit',
+                    is_visible=lambda:getattr(self,'show_all_options',True),
                               description='Require confirmation when exiting.',
                               field_name='confirm_exit'),
                 simple_option(title='Input validation',
+                    is_visible=lambda:getattr(self,'show_all_options',True),
                               description='In case of syntax errors, move the cursor to the error '
                                           'instead of showing a traceback of a SyntaxError.',
                               field_name='enable_input_validation'),
                 simple_option(title='Auto suggestion',
+                    is_visible=lambda:getattr(self,'show_all_options',True),
                               description='Auto suggest inputs by looking at the history. '
                                           'Pressing right arrow or Ctrl-E will complete the entry.',
                               field_name='enable_auto_suggest'),
                 Option(title='Accept input on enter',
+                    is_visible=lambda:getattr(self,'show_all_options',True),
                        description='Amount of ENTER presses required to execute input when the cursor '
                                    'is at the end of the input. (Note that META+ENTER will always execute.)',
                        get_current_value=lambda:str(self.accept_input_on_enter or 'meta-enter'),
@@ -446,82 +469,167 @@ class PythonInput(object):
                            CompletionVisualisation.MULTI_COLUMN:lambda:enable('completion_visualisation',CompletionVisualisation.MULTI_COLUMN),
                            CompletionVisualisation.TOOLBAR:lambda:enable('completion_visualisation',CompletionVisualisation.TOOLBAR),
                        }),
-                Option(title='Prompt',
-                       description="Visualisation of the prompt. ('>>>' or 'In [1]:')",
-                       get_current_value=lambda:self.prompt_style,
-                       get_values=lambda:dict((s,partial(enable,'prompt_style',s)) for s in self.all_prompt_styles)),
+                #I DISABLED THIS BECAUSE IT'S DEPRECATED NOW - NOW YOU USE 'SET STYLE'
+                # Option(title='Prompt',
+                #         is_visible=lambda:getattr(self,'show_all_options',True),
+                #        description="Visualisation of the prompt. ('>>>' or 'In [1]:')",
+                #        get_current_value=lambda:self.prompt_style,
+                #        get_values=lambda:dict((s,partial(enable,'prompt_style',s)) for s in self.all_prompt_styles)),
                 simple_option(title='Blank line after output',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
                               description='Insert a blank line after the output.',
                               field_name='insert_blank_line_after_output'),
                 simple_option(title='Show signature',
                               description='Display function signatures.',
                               field_name='show_signature'),
                 simple_option(title='Show docstring',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
                               description='Display function docstrings.',
                               field_name='show_docstring'),
                 simple_option(title='Show line numbers',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
                               description='Show line numbers when the input consists of multiple lines.',
                               field_name='show_line_numbers'),
                 simple_option(title='Show Meta+Enter message',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
                               description='Show the [Meta+Enter] message when this key combination is required to execute commands. ' +
                                           '(This is the case when a simple [Enter] key press will insert a newline.',
                               field_name='show_meta_enter_message'),
                 simple_option(title='Wrap lines',
                               description='Wrap lines instead of scrolling horizontally.',
                               field_name='wrap_lines'),
+                Option(title='Show Battery Life',
+
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+                       description='Should we show your laptop\'s battery life?\nIt\'s shown on the bottom right of the terminal.\nWhen it\'s green, that means your laptop is plugged in. When red, it means youre on battery power.',
+                       get_current_value=lambda:getattr(self,'show_battery_life','(Broken)'),
+                       get_values=lambda:{
+                           True:lambda:setattr(self,'show_battery_life',True),# print("Selected Llama"),
+                           False:lambda:setattr(self,'show_battery_life',False),# print("Selected Donkey"),
+                       }),
                 simple_option(title='Show status bar',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
                               description='Show the status bar at the bottom of the terminal.',
                               field_name='show_status_bar'),
                 simple_option(title='Show sidebar help',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
                               description='When the sidebar is visible, also show this help text.',
                               field_name='show_sidebar_help'),
                 simple_option(title='Highlight parenthesis',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
                               description='Highlight matching parenthesis, when the cursor is on or right after one.',
                               field_name='highlight_matching_parenthesis'),
+
             ]),
-            OptionCategory('rp Pseudo-Terminal',[
+            OptionCategory('Ryan Python',[
                 Option(title='Sand Creature',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
                        description='This is an option selection test that should print stuff',
-                       get_current_value=lambda:self.sand_creature,
+                       get_current_value=lambda:getattr(self,'sand_creature','(Broken)'),
                        get_values=lambda:{
                            "Option Llama":lambda:setattr(self,'sand_creature',"Option Llama"),# print("Selected Llama"),
                            "Option Donkey":lambda:setattr(self,'sand_creature',"Option Donkey"),# print("Selected Donkey"),
                            "Option Camel":lambda:doge(self),# print("Selected Camel"),
                        }),
+                Option(title='Show Last Assignable',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
+                       description='Should we show the variable in purple box on the bottom of the screen?',
+                       get_current_value=lambda:getattr(self,'show_last_assignable','(Broken)'),
+                       get_values=lambda:{
+                           True:lambda:setattr(self,'show_last_assignable',True),# print("Selected Llama"),
+                           False:lambda:setattr(self,'show_last_assignable',False),# print("Selected Donkey"),
+                       }),
                 Option(title='Space-Functions',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
                        description='Turning this on lets pressing the space bar autocomplete a \nfunction for you as well as adding parenthesis around it.\n(Its like pressing tab followed by the spacebar).',
                        get_current_value=lambda:"on" if ric.enable_space_autocompletions else "off",
                        get_values=lambda:{
                            "on":lambda:ric.enable_space_autocompletions.append(None),# print("Selected Llama"),
                            "off":lambda:ric.enable_space_autocompletions.clear(),# print("Selected Donkey"),
                        }),
+                Option(title='Completion Type',
+                       description='This option determines how autocompletion suggestions are made.\nIf set to \'good\', it will use Jedi to statically analyze your code, providing better insight.\nOtherwise, if set to \'fast\', it will perform mostly simple autocompletions, that will appear much faster.',
+                       get_current_value=lambda:"fast" if ric.completion_style==['fast'] else "good",
+                       get_values=lambda:{
+                           "fast" :lambda:ric.completion_style.__setitem__(0,'fast'),# print("Selected Llama"),
+                           "good" :lambda:ric.completion_style.__setitem__(0,'good'),# print("Selected Donkey"),
+                       }),
                 simple_option(title='Parenthesizer',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
                               description='bla',
                               field_name='show_parenthesis_automator'),
                 simple_option(title='Realtime Eval',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
                               description='bla',
                               field_name='show_realtime_input'),
                 simple_option(title='Show VARS',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
                               description='bla',
                               field_name='show_vars'),
+                Option(title='Debugger UI Height',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
+                       description='The height of the GUI when running debug()',
+                       get_current_value=lambda:str(ric.debug_height),
+                       get_values=lambda:{
+                            '5':lambda:set_debug_height(5),
+                            '10':lambda:set_debug_height(10),
+                            '15':lambda:set_debug_height(15),
+                            '20':lambda:set_debug_height(20),
+                            '25':lambda:set_debug_height(25),
+                            '30':lambda:set_debug_height(30),
+                            '35':lambda:set_debug_height(35),
+                            '40':lambda:set_debug_height(40),
+                            '45':lambda:set_debug_height(45),
+                            '50':lambda:set_debug_height(50),
+                            '55':lambda:set_debug_height(55),
+                            '60':lambda:set_debug_height(60),
+                            '65':lambda:set_debug_height(65),
+                            '70':lambda:set_debug_height(70),
+                            '75':lambda:set_debug_height(75),
+                            '80':lambda:set_debug_height(80),
+                            '85':lambda:set_debug_height(85),
+                            '90':lambda:set_debug_height(90),
+                            '95':lambda:set_debug_height(95),
+                            '100':lambda:set_debug_height(100),
+                       }),
             ]),
-            OptionCategory('Colors',[
+            OptionCategory('Color Themes',[
                 Option(title='Code',
                        description='Color scheme to use for the Python code.',
                        get_current_value=lambda:self._current_code_style_name,
                        get_values=lambda:dict(
                            (name,partial(self.use_code_colorscheme,name)) for name in self.code_styles)
                        ),
-                Option(title='User interface',
+                Option(title='User Interface',
                        description='Color scheme to use for the user interface.',
                        get_current_value=lambda:self._current_ui_style_name,
                        get_values=lambda:dict(
                            (name,partial(self.use_ui_colorscheme,name)) for name in self.ui_styles)
                        ),
                 simple_option(title='True color (24 bit)',
-                              description='Use 24 bit colors instead of 265 colors',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
+                              description='Use 24 bit colors instead of 265 colors\nThis is only supported on some terminal apps\nSome known to support it: Ubuntu\'s default terminal, MacOS iTerm',
                               field_name='true_color'),
             ]),
+            OptionCategory('This Menu',[
+                                Option(title='Show All Options',
+                       description='If turned on, will show more options in this menu.\nIf turned off, will try to keep this menu simple.',
+                       get_current_value=lambda:getattr(self,'show_all_options',False),
+                       get_values=lambda:{
+                           True:lambda:setattr(self,'show_all_options',True),# print("Selected Llama"),
+                           False:lambda:setattr(self,'show_all_options',False),# print("Selected Donkey"),
+                       }),
+
+            ]),
         ]
 
     def create_application(self):
