@@ -1,10 +1,16 @@
 #A dependency shotgun
 packages=[
+'pudb',
+'click',
+'icecream',
 'python-editor'
 'js2py',
+'inflect',
+'word2number',
 'pyflann',#TODO: This needs to be fixed. It's broken for python3. It needs to be fixed using 2to3, and then inlined into this rp package. This is needed for flann_dict
 'HTMLParser',
 'Pyperclip',
+'psutil',
 'colorama',
 'drawille',
 'exofrills',
@@ -41,6 +47,9 @@ packages=[
 'pytube',
 'sk-video',
 'blist',
+'ipython',
+'pypager',
+'scikit-image',
 ]
 def shotgun():
     for package in packages:
@@ -51,10 +60,12 @@ def shotgun():
         print(bar)
         from subprocess import run
         from os import name
-        if name=='nt':# We're on windows
-            run('pip3 install '+package,shell=True)# Might be prompted for a password
-        else:
-            run('sudo pip3 install '+package,shell=True)# Might be prompted for a password
+        from rp import pip_install
+        pip_install(package)
+        # if name=='nt':# We're on windows
+            # run('pip3 install '+package,shell=True)# Might be prompted for a password
+        # else:
+            # run('sudo pip3 install '+package,shell=True)# Might be prompted for a password
 try:
     shotgun()
 except:
